@@ -1,16 +1,17 @@
 
-from learning_loop_node.detector.outbox import Outbox
+from learning_loop_node.detector.outbox.outbox import Outbox
 from PIL import Image
 import os
 import numpy as np
 import pytest
 import shutil
+from multiprocessing import Event
 
 
 @pytest.fixture()
 def outbox():
-    os.environ['ORGANIZATION'] = 'zauberzeug'
-    os.environ['PROJECT'] = 'demo'
+    os.environ['LOOP_ORGANIZATION'] = 'zauberzeug'
+    os.environ['LOOP_PROJECT'] = 'demo'
     outbox = Outbox()
     shutil.rmtree(outbox.path, ignore_errors=True)
     os.mkdir(outbox.path)
@@ -28,11 +29,13 @@ def test_files_are_deleted_after_sending(outbox: Outbox):
 
     img = Image.new('RGB', (60, 30), color=(73, 109, 137))
     img.save(f'{outbox.path}/test/image.jpg')
+    uploader = outbox.create_upload_process(Event())
 
     items = outbox.get_data_files()
     assert len(items) == 1
 
-    outbox.upload()
+    uploader.upload()
+
     items = outbox.get_data_files()
     assert len(items) == 0
 
